==> phoenix_widgets-1.12.0.tar.gz: example/lib/phoenix_product_tiles_page.dart <==
import 'package:flutter/material.dart';
import 'package:flutter_svg/flutter_svg.dart';
import 'package:phoenix_widgets/phoenix_widgets.dart';

class PhoenixProductTilesPage extends StatefulWidget {
  const PhoenixProductTilesPage({Key? key}) : super(key: key);

  @override
  _PhoenixProductTilesPageState createState() => _PhoenixProductTilesPageState();
}

class _PhoenixProductTilesPageState extends State<PhoenixProductTilesPage> {
  final List<PhoenixProductItem> _items = [
    PhoenixProductItem(
        "Tile 1",
        Image.asset(
          "assets/tab_home.png",
          width: 45,
          height: 45,
        )),
    PhoenixProductItem(
        "Tile 2",
        Image.asset(
          "assets/tab_home.png",
          width: 45,
          height: 45,
        )),
    PhoenixProductItem(
        "Tile 3",
        Image.asset(
          "assets/tab_home.png",
          width: 45,
          height: 45,
        )),
    PhoenixProductItem(
        "Tile 4",
        Image.asset(
          "assets/tab_home.png",
          width: 45,
          height: 45,
        )),
    PhoenixProductItem(
        "Tile 5",
        Image.asset(
          "assets/tab_home.png",
          width: 45,
          height: 45,
        )),
    PhoenixProductItem(
        "Tile 6",
        Image.asset(
          "assets/tab_home.png",
          width: 45,
          height: 45,
        )),
    PhoenixProductItem(
        "Tile 7",
        SvgPicture.asset(
          "assets/images.svg",
          width: 45,
          height: 45,
        ),
        "Coming Soon"),
    PhoenixProductItem(
        "Tile 8",
        SvgPicture.asset(
          "assets/images.svg",
          width: 45,
          height: 45,
        ),
        "Coming Soon"),
  ];

  void _onTap(int index) {
    ScaffoldMessenger.of(context)
      ..removeCurrentSnackBar()
      ..showSnackBar(SnackBar(content: Text("Tile ${index + 1} is clicked")));
  }

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      backgroundColor: Colors.white,
      appBar: AppBar(
        title: const Text('Phoenix Product Tiles Sample'),
      ),
      body: CustomScrollView(
        slivers: [
          PhoenixProductTiles(
            onTap: _onTap,
            items: _items,
          )
        ],
      ),
    );
  }
}

==> phoenix_widgets-1.16.5.tar.gz: example/lib/phoenix_product_tiles_page.dart <==
import 'package:flutter/material.dart';
import 'package:flutter_svg/flutter_svg.dart';
import 'package:phoenix_widgets/phoenix_widgets.dart';

class PhoenixProductTilesPage extends StatefulWidget {
  const PhoenixProductTilesPage({Key? key}) : super(key: key);

  @override
  _PhoenixProductTilesPageState createState() =>
      _PhoenixProductTilesPageState();
}

class _PhoenixProductTilesPageState extends State<PhoenixProductTilesPage> {
  final List<PhoenixProductItem> _items = [
    PhoenixProductItem(
        "Tile 1",
        Image.asset(
          "assets/tab_home.png",
          width: 45,
          height: 45,
        )),
    PhoenixProductItem(
        "Tile 2",
        Image.asset(
          "assets/tab_home.png",
          width: 45,
          height: 45,
        )),
    PhoenixProductItem(
        "Tile 3",
        Image.asset(
          "assets/tab_home.png",
          width: 45,
          height: 45,
        )),
    PhoenixProductItem(
        "Tile 4",
        Image.asset(
          "assets/tab_home.png",
          width: 45,
          height: 45,
        )),
    PhoenixProductItem(
        "Tile 5",
        Image.asset(
          "assets/tab_home.png",
          width: 45,
          height: 45,
        )),
    PhoenixProductItem(
        "Tile 6",
        Image.asset(
          "assets/tab_home.png",
          width: 45,
          height: 45,
        )),
    PhoenixProductItem(
        "Tile 7",
        SvgPicture.asset(
          "assets/images.svg",
          width: 45,
          height: 45,
        ),
        label: "Coming Soon"),
    PhoenixProductItem(
        "Tile 8",
        SvgPicture.asset(
          "assets/images.svg",
          width: 45,
          height: 45,
        ),
        label: "Coming Soon"),
  ];

  void _onTap(int index) {
    ScaffoldMessenger.of(context)
      ..removeCurrentSnackBar()
      ..showSnackBar(SnackBar(content: Text("Tile ${index + 1} is clicked")));
  }

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      backgroundColor: Colors.white,
      appBar: AppBar(
        title: const Text('Phoenix Product Tiles Sample'),
      ),
      body: CustomScrollView(
        slivers: [
          PhoenixProductTiles(
            onTap: _onTap,
            items: _items,
          )
        ],
      ),
    );
  }
}
